@@ -1,4 +1,4 @@
 # SPDX-License-Identifier: BSD-3-Clause
 from .error import MqttError, MqttCodeError
-from .client import Client
-from .version import __version__
\ No newline at end of file
+from .client import Client, Will
+from .version import __version__
